Skip to main content
skill CX Codex

tilegym-converting-cutile-to-triton — Claude Code skill: port cuTile

Turns cuTile GPU kernels into Triton ones through gated phases: analyze, convert, validate, test, benchmark. Debugging of failed ports included.

Install into Claude Code · Skills CLI (Vercel) All methods and platforms ↓
npx skills add NVIDIA/skills --skill tilegym-converting-cutile-to-triton -a claude-code
Open on GitHub

What tilegym-converting-cutile-to-triton does

The skill takes kernels written with @ct.kernel and rewrites them for @triton.jit. Work runs in phases — analysis first, then conversion, validation, tests and benchmarking — with gates in between. A failing test or benchmark stops the run until you fix it.

Reference docs cover cuTile-to-Triton API pairs, debugging and file placement. Special cases get their own pages: dual layouts behind the transpose flag, autotuned grids via META, and attention kernels such as Gemma FMHA and GQA. For 2D block tiles the skill insists on tl.make_tensor_descriptor rather than raw tl.load with a mask, since that shortcut is a common source of slowdowns. When Triton comes out slower, checklists for GEMM, BMM and attention optimization are there to work through.

One thing to plan for: validation runs against the TileGym test suite with pytest tests/ops/test_<op>.py -k "triton" -vs, so without those tests there is no gate to pass. Debugging covers cudaErrorIllegalAddress, shape mismatches and numerical mismatches.

What it helps with

  • rewrite a cuTile kernel for Triton without dropping logic
  • track down a cudaErrorIllegalAddress after a port
  • fix shape or numerical mismatches in an existing translation
  • build a dual-layout kernel with transpose and a META grid
  • recover performance in an attention kernel that regressed

Example prompts for the agent

  • convert the @ct.kernel in kernels/attention.py to @triton.jit
  • my Triton port throws cudaErrorIllegalAddress, find the cause
  • set up dual layouts for transpose=True and transpose=False with META

How to install tilegym-converting-cutile-to-triton

1Skills CLI (Vercel)

npx skills add NVIDIA/skills --skill tilegym-converting-cutile-to-triton -a claude-code

2Manually: put the files in place

~/.claude/skills/tilegym-converting-cutile-to-triton/SKILL.md

Copy the whole skill folder; for one project use .claude/skills/tilegym-converting-cutile-to-triton/

Step by step, with commands for each platform: How to install skills in Claude Code: five ways

Questions about tilegym-converting-cutile-to-triton

How do I install tilegym-converting-cutile-to-triton in Claude?

Run npx skills add NVIDIA/skills --skill tilegym-converting-cutile-to-triton -a claude-code. The skill file then lands at ~/.claude/skills/tilegym-converting-cutile-to-triton/SKILL.md.

What does tilegym-converting-cutile-to-triton do?

It converts cuTile GPU kernels written with @ct.kernel into Triton kernels using @triton.jit. It also helps debug translations you already have and bring their speed back up.

Does it work outside the TileGym repository?

The validation phase expects TileGym pytest targets such as pytest tests/ops/test_<op>.py -k "triton" -vs. Without that suite you lose the gate that catches a broken conversion before benchmarking.

Similar skills

Everything for AI and ML →

From the same set194

tao-port-huggingface-model This skill ports a HuggingFace computer vision model into NVIDIA TAO Toolkit. Use it to build training, export, deployment, and container checks. CX Codex +1 1,600installs tao-finetune-clip A skill that walks an agent through CLIP training, zero-shot classification, embedding extraction and ONNX or TensorRT export in NVIDIA TAO. CX Codex +1 1,600installs tao-finetune-cosmos-embed Configures Docker runs for Cosmos-Embed1 inside NVIDIA TAO, enabling text-to-video retrieval, model fine-tuning, evaluation, and artifact exports. CX Codex +1 1,600installs tilegym-converting-cutile-to-julia Translates cuTile Python GPU kernels into cuTile.jl for Julia with 1-based indexing and column-major memory layout. Useful when porting workloads to Blackwell GPUs. CX Codex +1 1,500installs tilegym-cutile-autotuning Walks your agent through wiring autotuning into CuTile kernels: search once, cache the winner, launch straight from the cache. CX Codex +1 1,500installs cuopt-multi-objective-exploration Traces Pareto frontiers for multi-objective optimization using NVIDIA cuOpt. It maps tradeoffs between competing goals when no single weighting exists. CX Codex +1 1,300installs jetson-diagnostic Collects a read-only Jetson snapshot covering device identity, memory, GPU, thermal state, power, storage, services and processes. Use it to inspect a live host. CX Codex +1 1,300installs jetson-headless-mode Plans a headless-mode switch on Jetson and applies only safe, reversible changes: drops the graphical target and non-essential daemons. CX Codex +1 1,200installs

Project sponsors

Companies that keep this analytics open
Gold sponsor

Impressions, clicks and code copies — open statistics. We keep the numbers public for the same reason NeBlask itself is public. Become a sponsor